@@ -4,24 +4,16 @@
 
 import click
 from dxi._lib.util import boolean_based_system_exit
-from dxi.database.dxi_dboperations import DXIDBOperations
-from dxi.database.dxi_dboperations import DXIDBOperationsConstants
-from dxi.database.dxi_delete import DeleteConstants
-from dxi.database.dxi_delete import DXIDelete
-from dxi.database.dxi_provisiondsource import DXIProvisionDsource
-from dxi.database.dxi_provisiondsource import ProvisionDsourceConstants
-from dxi.database.dxi_provisionvdb import DXIProvisionVDB
-from dxi.database.dxi_provisionvdb import ProvisionVDBConstants
-from dxi.database.dxi_refresh import DXIRefresh
-from dxi.database.dxi_refresh import VDBRefreshConstants
-from dxi.database.dxi_rewind import DXIRewind
-from dxi.database.dxi_rewind import VDBRewindConstants
+from dxi.database.dxi_ingest import DXIProvisionDsource
+from dxi.database.dxi_ingest import DXIProvisionDsourceConstants
+from dxi.database.dxi_provision import DXIVdb
+from dxi.database.dxi_provision import DXIVdbConstants
 
 
 @click.group()
 def database():
     """
-    database is a group command perform dsource or vdb operations
+    Delphix Dsource, VDB and vFile operations
     """
     pass
 
@@ -54,33 +46,33 @@ def database():
 @click.option(
     "--time_flow", help="Name of the timeflow to refresh a VDB", default=None
 )
-@click.option("--engine", default=VDBRefreshConstants.ENGINE_ID)
+@click.option("--engine", default=DXIVdbConstants.ENGINE_ID)
 @click.option(
     "--single_thread",
     help="Run as a single thread",
-    default=VDBRefreshConstants.SINGLE_THREAD,
+    default=DXIVdbConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     help="The number of seconds to wait between job polls.",
-    default=VDBRefreshConstants.POLL,
+    default=DXIVdbConstants.POLL,
 )
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=VDBRefreshConstants.CONFIG,
+    default=DXIVdbConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=VDBRefreshConstants.LOG_FILE_PATH,
+    default=DXIVdbConstants.LOG_FILE_PATH,
 )
 @click.option(
     "--parallel",
     type=click.INT,
     help="Limit number of jobs to maxjob.",
-    default=VDBRefreshConstants.PARALLEL,
+    default=DXIVdbConstants.PARALLEL,
 )
 def refresh(
     name,
@@ -95,25 +87,26 @@ def refresh(
     parallel,
 ):
     """
-Refresh a Delphix VDB\n
-
-dxi database refresh --name testdb --time_stamp 2021-02-04T04:43:58.000Z
+Refresh a Delphix VDB
     """
 
-    obj = DXIRefresh(
-        name=name,
+    obj = DXIVdb(
         engine=engine,
-        time_stamp_type=time_stamp_type,
-        time_stamp=time_stamp,
         single_thread=single_thread,
-        time_flow=time_flow,
         poll=poll,
         config=config,
         log_file_path=log_path,
         parallel=parallel,
     )
 
-    boolean_based_system_exit(obj.refresh())
+    boolean_based_system_exit(
+        obj.refresh(
+            name,
+            time_stamp_type=time_stamp_type,
+            time_stamp=time_stamp,
+            time_flow=time_flow,
+        )
+    )
 
 
 # Rewind Command
@@ -146,33 +139,33 @@ dxi database refresh --name testdb --time_stamp 2021-02-04T04:43:58.000Z
     help="Type of database: oracle, mssql, ase, vfiles",
     default=None,
 )
-@click.option("--engine", default=VDBRewindConstants.ENGINE_ID)
+@click.option("--engine", default=DXIVdbConstants.ENGINE_ID)
 @click.option(
     "--single_thread",
     help="Run as a single thread",
-    default=VDBRewindConstants.SINGLE_THREAD,
+    default=DXIVdbConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     help="The number of seconds to wait between job polls.",
-    default=VDBRewindConstants.POLL,
+    default=DXIVdbConstants.POLL,
 )
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=VDBRewindConstants.CONFIG,
+    default=DXIVdbConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=VDBRewindConstants.LOG_FILE_PATH,
+    default=DXIVdbConstants.LOG_FILE_PATH,
 )
 @click.option(
     "--parallel",
     type=click.INT,
     help="Limit number of jobs to maxjob.",
-    default=VDBRefreshConstants.PARALLEL,
+    default=DXIVdbConstants.PARALLEL,
 )
 def rewind(
     name,
@@ -188,72 +181,71 @@ def rewind(
 ):
     """
 Rewinds a VDB
-
-dxi database rewind --name testdb --time_stamp 2021-02-04T04:43:58.000Z
-
     """
 
-    obj = DXIRewind(
-        name=name,
+    obj = DXIVdb(
         engine=engine,
-        time_stamp_type=timestamp_type,
-        time_stamp=time_stamp,
         single_thread=single_thread,
-        database_type=database_type,
         poll=poll,
         config=config,
         log_file_path=log_path,
         parallel=parallel,
     )
-
-    boolean_based_system_exit(obj.rewind())
+    boolean_based_system_exit(
+        obj.rewind(
+            name,
+            time_stamp_type=timestamp_type,
+            time_stamp=time_stamp,
+            database_type=database_type,
+        )
+    )
 
 
 # Delete command
 @database.command()
 @click.option(
     "--name",
-    default=DeleteConstants.NAME,
+    default=None,
     help="Name of dataset(s) in Delphix to execute against",
 )
 @click.option(
     "--db-type",
-    default=DeleteConstants.TYPE,
+    default=DXIVdbConstants.TYPE,
     help="Type of the dataset to delete. vdb | dsource",
 )
 @click.option(
     "--force",
     is_flag=True,
-    default=DeleteConstants.FORCE,
+    default=DXIVdbConstants.FORCE,
     help="Force delete the dataset",
 )
-@click.option("--engine", default=DeleteConstants.ENGINE_ID)
+@click.option("--engine", default=DXIVdbConstants.ENGINE_ID)
 @click.option(
     "--single_thread",
     help="Run as a single thread",
-    default=DeleteConstants.SINGLE_THREAD,
+    default=DXIVdbConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--parallel",
     type=click.INT,
     help="Limit number of jobs to maxjob.",
-    default=DeleteConstants.PARALLEL,
+    default=DXIVdbConstants.PARALLEL,
 )
 @click.option(
     "--poll",
     help="The number of seconds to wait between job polls.",
-    default=DeleteConstants.POLL,
+    default=DXIVdbConstants.POLL,
 )
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=DeleteConstants.CONFIG,
+    default=DXIVdbConstants.CONFIG,
 )
 @click.option(
     "--log_path",
     help="The path to the logfile you want to use.",
-    default=DeleteConstants.LOG_FILE_PATH,
+    default=DXIVdbConstants.LOG_FILE_PATH,
 )
 def delete(
     name,
@@ -269,18 +261,15 @@ def delete(
     """
     Delete a Delphix dSource or VDB
     """
-    delete_obj = DXIDelete(
-        name=name,
-        db_type=db_type,
-        force=force,
-        parallel=parallel,
+    obj = DXIVdb(
         engine=engine,
+        single_thread=single_thread,
         poll=poll,
         config=config,
         log_file_path=log_path,
-        single_thread=single_thread,
+        parallel=parallel,
     )
-    boolean_based_system_exit(delete_obj.delete_db())
+    boolean_based_system_exit(obj.delete(name, db_type=db_type, force=force))
 
 
 #############################################
@@ -290,50 +279,50 @@ def delete(
 @database.command()
 @click.option(
     "--engine",
-    default=DXIDBOperationsConstants.ENGINE_ID,
+    default=DXIVdbConstants.ENGINE_ID,
     help="Name of the engine to run this operation on",
 )
 @click.option(
     "--single_thread",
     help="Run as a single thread",
-    default=DXIDBOperationsConstants.SINGLE_THREAD,
+    default=DXIVdbConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     type=click.INT,
     help="The number of seconds to wait between job polls.",
-    default=DXIDBOperationsConstants.POLL,
+    default=DXIVdbConstants.POLL,
 )
 @click.option(
     "--parallel",
     type=click.INT,
     help="Limit number of jobs to maxjob.",
-    default=DXIDBOperationsConstants.PARALLEL,
+    default=DXIVdbConstants.PARALLEL,
 )
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=DXIDBOperationsConstants.CONFIG,
+    default=DXIVdbConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=DXIDBOperationsConstants.LOG_FILE_PATH,
+    default=DXIVdbConstants.LOG_FILE_PATH,
 )
 def list(engine, single_thread, parallel, poll, config, log_path):
     """
     List all datasets on an engine
     """
-    ops_obj = DXIDBOperations(
+    obj = DXIVdb(
         engine=engine,
-        parallel=parallel,
-        poll=poll,
-        config_file=config,
-        log_file_path=log_path,
         single_thread=single_thread,
+        poll=poll,
+        config=config,
+        log_file_path=log_path,
+        parallel=parallel,
     )
-    boolean_based_system_exit(ops_obj.list())
+    boolean_based_system_exit(obj.list())
 
 
 # db-start
@@ -347,36 +336,36 @@ def list(engine, single_thread, parallel, poll, config, log_path):
 @click.option("--group", help="Group where the dataset resides", default=None)
 @click.option(
     "--engine",
-    default=DXIDBOperationsConstants.ENGINE_ID,
+    default=DXIVdbConstants.ENGINE_ID,
     help="Name of the engine to run this operation on",
 )
 @click.option(
     "--single_thread",
     help="Run as a single thread",
-    default=DXIDBOperationsConstants.SINGLE_THREAD,
+    default=DXIVdbConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     type=click.INT,
     help="The number of seconds to wait between job polls.",
-    default=DXIDBOperationsConstants.POLL,
+    default=DXIVdbConstants.POLL,
 )
 @click.option(
     "--parallel",
     type=click.INT,
     help="Limit number of jobs to maxjob.",
-    default=DXIDBOperationsConstants.PARALLEL,
+    default=DXIVdbConstants.PARALLEL,
 )
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=DXIDBOperationsConstants.CONFIG,
+    default=DXIVdbConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=DXIDBOperationsConstants.LOG_FILE_PATH,
+    default=DXIVdbConstants.LOG_FILE_PATH,
 )
 def start(
     name, group, engine, single_thread, parallel, poll, config, log_path
@@ -384,13 +373,13 @@ def start(
     """
     Starts a virtual dataset by name and group
     """
-    ops_obj = DXIDBOperations(
+    ops_obj = DXIVdb(
         engine=engine,
-        parallel=parallel,
-        poll=poll,
-        config_file=config,
-        log_file_path=log_path,
         single_thread=single_thread,
+        poll=poll,
+        config=config,
+        parallel=parallel,
+        log_file_path=log_path,
     )
     boolean_based_system_exit(ops_obj.start(name=name, group=group))
 
@@ -406,46 +395,46 @@ def start(
 @click.option("--group", help="Group where the dataset resides", default=None)
 @click.option(
     "--engine",
-    default=DXIDBOperationsConstants.ENGINE_ID,
+    default=DXIVdbConstants.ENGINE_ID,
     help="Name of the engine to run this operation on",
 )
 @click.option(
     "--single_thread",
     help="Run as a single thread",
-    default=DXIDBOperationsConstants.SINGLE_THREAD,
+    default=DXIVdbConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     type=click.INT,
     help="The number of seconds to wait between job polls.",
-    default=DXIDBOperationsConstants.POLL,
+    default=DXIVdbConstants.POLL,
 )
 @click.option(
     "--parallel",
     type=click.INT,
     help="Limit number of jobs to maxjob.",
-    default=DXIDBOperationsConstants.PARALLEL,
+    default=DXIVdbConstants.PARALLEL,
 )
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=DXIDBOperationsConstants.CONFIG,
+    default=DXIVdbConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=DXIDBOperationsConstants.LOG_FILE_PATH,
+    default=DXIVdbConstants.LOG_FILE_PATH,
 )
 def stop(name, group, engine, single_thread, parallel, poll, config, log_path):
     """
     Stop a virtual dataset by name and group (optional)
     """
-    ops_obj = DXIDBOperations(
+    ops_obj = DXIVdb(
         engine=engine,
-        parallel=parallel,
         poll=poll,
-        config_file=config,
+        config=config,
+        parallel=parallel,
         log_file_path=log_path,
         single_thread=single_thread,
     )
@@ -463,36 +452,36 @@ def stop(name, group, engine, single_thread, parallel, poll, config, log_path):
 @click.option("--group", help="Group where the dataset resides", default=None)
 @click.option(
     "--engine",
-    default=DXIDBOperationsConstants.ENGINE_ID,
+    default=DXIVdbConstants.ENGINE_ID,
     help="Name of the engine to run this operation on",
 )
 @click.option(
     "--single_thread",
     help="Run as a single thread",
-    default=DXIDBOperationsConstants.SINGLE_THREAD,
+    default=DXIVdbConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     type=click.INT,
     help="The number of seconds to wait between job polls.",
-    default=DXIDBOperationsConstants.POLL,
+    default=DXIVdbConstants.POLL,
 )
 @click.option(
     "--parallel",
     type=click.INT,
     help="Limit number of jobs to maxjob.",
-    default=DXIDBOperationsConstants.PARALLEL,
+    default=DXIVdbConstants.PARALLEL,
 )
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=DXIDBOperationsConstants.CONFIG,
+    default=DXIVdbConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=DXIDBOperationsConstants.LOG_FILE_PATH,
+    default=DXIVdbConstants.LOG_FILE_PATH,
 )
 def enable(
     name, group, engine, single_thread, parallel, poll, config, log_path
@@ -500,13 +489,13 @@ def enable(
     """
     Enable a virtual dataset by name and group(optional)
     """
-    ops_obj = DXIDBOperations(
+    ops_obj = DXIVdb(
         engine=engine,
-        parallel=parallel,
-        poll=poll,
-        config_file=config,
-        log_file_path=log_path,
         single_thread=single_thread,
+        poll=poll,
+        config=config,
+        parallel=parallel,
+        log_file_path=log_path,
     )
     boolean_based_system_exit(ops_obj.enable(name=name, group=group))
 
@@ -528,36 +517,36 @@ def enable(
 )
 @click.option(
     "--engine",
-    default=DXIDBOperationsConstants.ENGINE_ID,
+    default=DXIVdbConstants.ENGINE_ID,
     help="Name of the engine to run this operation on",
 )
 @click.option(
     "--single_thread",
     help="Run as a single thread",
-    default=DXIDBOperationsConstants.SINGLE_THREAD,
+    default=DXIVdbConstants.SINGLE_THREAD,
     is_flag=True,
 )
 @click.option(
     "--poll",
     type=click.INT,
     help="The number of seconds to wait between job polls.",
-    default=DXIDBOperationsConstants.POLL,
+    default=DXIVdbConstants.POLL,
 )
 @click.option(
     "--parallel",
     type=click.INT,
     help="Limit number of jobs to maxjob.",
-    default=DXIDBOperationsConstants.PARALLEL,
+    default=DXIVdbConstants.PARALLEL,
 )
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=DXIDBOperationsConstants.CONFIG,
+    default=DXIVdbConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=DXIDBOperationsConstants.LOG_FILE_PATH,
+    default=DXIVdbConstants.LOG_FILE_PATH,
 )
 def disable(
     name, group, force, engine, single_thread, parallel, poll, config, log_path
@@ -565,13 +554,13 @@ def disable(
     """
     Disable a virtual dataset by name and group(optional)
     """
-    ops_obj = DXIDBOperations(
+    ops_obj = DXIVdb(
         engine=engine,
-        parallel=parallel,
-        poll=poll,
-        config_file=config,
-        log_file_path=log_path,
         single_thread=single_thread,
+        poll=poll,
+        config=config,
+        log_file_path=log_path,
+        parallel=parallel,
     )
     boolean_based_system_exit(
         ops_obj.disable(name=name, group=group, force=force)
@@ -582,10 +571,10 @@ def disable(
 #
 @database.command()
 @click.option(
-    "--dsource_name", required=True, help="Name of the dSource to create"
+    "--source-name", required=True, help="Name of the dSource to create"
 )
 @click.option(
-    "--single_thread",
+    "--single-thread",
     help="Run as a single thread. False if running multiple threads.",
     default=False,
     type=click.BOOL,
@@ -659,12 +648,12 @@ def disable(
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=ProvisionDsourceConstants.CONFIG,
+    default=DXIProvisionDsourceConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=ProvisionDsourceConstants.LOG_FILE_PATH,
+    default=DXIProvisionDsourceConstants.LOG_FILE_PATH,
 )
 @click.option(
     "--version",
@@ -673,13 +662,51 @@ def disable(
     is_flag=True,
     default=True,
 )
-@click.option("--engine", default=ProvisionDsourceConstants.ENGINE_ID)
-def link_oracle(
+@click.option("--source-user", help="Environment username", default="delphix")
+@click.option("--stage-user", help="Stage username", default="delphix")
+@click.option("--stage-repo", help="Stage repository", default="delphix")
+@click.option(
+    "--stage-instance", help="Name of the PPT instance", default=None
+)
+@click.option("--stage-env", help="Name of the PPT server", default=None)
+@click.option(
+    "--backup-user-pwd",
+    help="Password of the shared backup path",
+    default=None,
+)
+@click.option(
+    "--backup-user", help="User of the shared backup path", default=None
+)
+@click.option(
+    "--use-recent-backup",
+    help="Delphix will try to load the most recent backup. MSSQL only",
+    default=True,
+)
+@click.option(
+    "--validated-sync-mode",
+    help="Delphix will try to load the most recent backup. MSSQL only",
+    default="TRANSACTION_LOG",
+)
+@click.option(
+    "--delphix-managed",
+    help="Delphix will try to load the most recent backup. MSSQL only",
+    default=True,
+)
+@click.option(
+    "--initial-load-type",
+    help="Delphix will try to load the most recent backup. MSSQL only",
+    default=None,
+)
+@click.option(
+    "--backup-path", help="Path to the ASE/MSSQL backups", default=None
+)
+@click.option("--engine", default=DXIProvisionDsourceConstants.ENGINE_ID)
+def ingest(
     engine,
     ip_addr,
     env_name,
     group,
-    dsource_name,
+    source_name,
     db_user,
     db_passwd,
     envinst,
@@ -697,35 +724,58 @@ def link_oracle(
     poll,
     config,
     version,
+    stage_user,
+    stage_repo,
+    stage_instance,
+    stage_env,
+    backup_user_pwd,
+    backup_user,
+    use_recent_backup,
+    initial_load_type,
+    validated_sync_mode,
+    delphix_managed,
+    backup_path,
 ):
     """
     Provision a Delphix dSource
     """
     obj = DXIProvisionDsource(
         engine=engine,
+        single_thread=single_thread,
+        parallel=parallel,
+        poll=poll,
+        config=config,
+        version=version,
+        log_file_path=log_path,
+    )
+    obj.ingest(
         ip_addr=ip_addr,
         env_name=env_name,
         dx_group=group,
-        dsource_name=dsource_name,
+        dsource_name=source_name,
         db_user=db_user,
         db_passwd=db_passwd,
         db_install_path=envinst,
         db_type=db_type,
         num_connections=num_connections,
         logsync=logsync,
-        single_thread=single_thread,
         files_per_set=files_per_set,
         rman_channels=rman_channels,
         port_num=port_num,
         sync_mode=sync_mode,
         source_user=source_user,
-        log_file_path=log_path,
-        parallel=parallel,
-        poll=poll,
-        config=config,
-        version=version,
+        stage_user=stage_user,
+        stage_repo=stage_repo,
+        stage_instance=stage_instance,
+        stage_env=stage_env,
+        backup_loc_passwd=backup_user_pwd,
+        backup_loc_user=backup_user,
+        load_from_backup=use_recent_backup,
+        initial_load_type=initial_load_type,
+        validated_sync_mode=validated_sync_mode,
+        delphix_managed=delphix_managed,
+        backup_path=backup_path,
     )
-    obj.execute()
 
 
 # MSSQL dSource
@@ -766,7 +816,7 @@ def link_oracle(
 )
 @click.option(
     "--sync_mode",
-    help="\b\nMSSQL validated sync mode \n"
+    help="\bMSSQL validated sync mode \n"
     "TRANSACTION_LOG|FULL_OR_DIFFERENTIAL|FULL|NONE",
     default="FULL",
 )
@@ -818,12 +868,12 @@ def link_oracle(
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=ProvisionDsourceConstants.CONFIG,
+    default=DXIProvisionDsourceConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=ProvisionDsourceConstants.LOG_FILE_PATH,
+    default=DXIProvisionDsourceConstants.LOG_FILE_PATH,
 )
 @click.option(
     "--version",
@@ -844,7 +894,7 @@ def link_oracle(
     is_flag=True,
     default=True,
 )
-@click.option("--engine", default=ProvisionDsourceConstants.ENGINE_ID)
+@click.option("--engine", default=DXIProvisionDsourceConstants.ENGINE_ID)
 def link_mssql(
     engine,
     env_name,
@@ -856,7 +906,6 @@ def link_mssql(
     logsync,
     single_thread,
     backup_path,
-    # sync_mode,
     source_user,
     stage_user,
     stage_repo,
@@ -874,12 +923,21 @@ def link_mssql(
     config,
     validated_sync_mode,
     version,
+    log_path,
 ):
     """
     Provision a Delphix MSSQL dSource
     """
     obj = DXIProvisionDsource(
         engine=engine,
+        single_thread=single_thread,
+        parallel=parallel,
+        poll=poll,
+        config=config,
+        version=version,
+        log_file_path=log_path,
+    )
+    obj.ingest(
         env_name=env_name,
         dx_group=dx_group,
         dsource_name=dsource_name,
@@ -887,9 +945,7 @@ def link_mssql(
         db_passwd=db_passwd,
         db_type=db_type,
         logsync=logsync,
-        single_thread=single_thread,
         backup_path=backup_path,
-        # sync_mode=sync_mode,
         source_user=source_user,
         stage_user=stage_user,
         stage_repo=stage_repo,
@@ -903,12 +959,7 @@ def link_mssql(
         delphix_managed=delphix_managed,
         initial_load_type=initial_load_type,
         envinst=envinst,
-        parallel=parallel,
-        poll=poll,
-        config=config,
-        version=version,
     )
-    obj.execute()
 
 
 # Provision a Dephix VDB
@@ -965,14 +1016,14 @@ def link_mssql(
 )
 @click.option(
     "--timestamp",
-    help="\b\nThe Delphix semantic for the point in time \n"
-    "from which you want to provision your VDB.",
+    help="\bThe Delphix semantic for the point in time\n "
+    "from which you want to ingest your VDB.",
     default="LATEST",
 )
 @click.option(
     "--mntpoint",
     help="The identifier of the instance in Delphix.",
-    default="/mnt/provision",
+    default="/mnt/ingest",
 )
 @click.option(
     "--parallel", help="Limit number of jobs to maxjob.", type=click.INT
@@ -986,12 +1037,12 @@ def link_mssql(
 @click.option(
     "--config",
     help="The path to the dxtools.conf file.",
-    default=ProvisionVDBConstants.CONFIG,
+    default=DXIVdbConstants.CONFIG,
 )
 @click.option(
     "--log-path",
     help="The path to the logfile you want to use.",
-    default=ProvisionVDBConstants.LOG_FILE_PATH,
+    default=DXIVdbConstants.LOG_FILE_PATH,
 )
 @click.option(
     "--version",
@@ -1000,7 +1051,7 @@ def link_mssql(
     is_flag=True,
     default=True,
 )
-@click.option("--engine", default=ProvisionVDBConstants.ENGINE_ID)
+@click.option("--engine", default=DXIVdbConstants.ENGINE_ID)
 def provision(
     engine,
     source_name,
@@ -1027,15 +1078,21 @@ def provision(
     """
     Provision a Delphix VDB
     """
-    obj = DXIProvisionVDB(
+    obj = DXIVdb(
         engine=engine,
-        source_db=source_name,
-        db=db_name,
-        db_type=db_type,
-        target_grp=group,
-        env_name=env_name,
+        single_thread=single_thread,
+        poll=poll,
+        config=config,
+        log_file_path=log_path,
+        parallel=parallel,
+    )
+    obj.provision(
+        group,
+        source_name,
+        db_name,
+        db_type,
+        env_name,
         timestamp=timestamp,
-        mntpoint=mntpoint,
         timestamp_type=timestamp_type,
         prerefresh=prerefresh,
         postrefresh=postrefresh,
@@ -1043,15 +1100,9 @@ def provision(
         postrollback=postrollback,
         configure_clone=configure_clone,
         envinst=envinst,
-        single_thread=single_thread,
-        parallel=parallel,
-        config=config,
-        log_file_path=log_path,
-        poll=poll,
-        version=version,
+        mntpoint=mntpoint,
     )
-    obj.provision()
 
 
 if __name__ == "__main__":
-    refresh()
+    provision()
