@@ -35,8 +35,8 @@ class DXIBranchConstants(object):
 
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "config/dxtools.conf"
-    LOG_FILE_PATH = "logs/dxi_branch.log"
+    CONFIG = "../../dxi-data/config/dxtools.conf"
+    LOG_FILE_PATH = "../../dxi-data/logs/"
     ENGINE_ID = "default"
     PARALLEL = 5
     TYPE = None
