@@ -22,8 +22,8 @@ class DXIContainerConstants(object):
     ALL_DBS = False
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "config/dxtools.conf"
-    LOG_FILE_PATH = "logs/dxi_container.log"
+    CONFIG = "../../dxi-data/config/dxtools.conf"
+    LOG_FILE_PATH = "../../dxi-data/logs/"
     BCK_FILE = None
     USE_BACKUP = False
     CREATE_BACKUP = False
