@@ -43,8 +43,8 @@ class EnvironmentConstants(object):
 
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "config/dxtools.conf"
-    LOG_FILE_PATH = "logs/dxi_environment.log"
+    CONFIG = "../../dxi-data/config/dxtools.conf"
+    LOG_FILE_PATH = "../../dxi-data/logs/"
     ENGINE_ID = "default"
     PARALLEL = 5
     TYPE = None
@@ -191,7 +191,7 @@ class DXIEnvironment(DXIBase):
         self.action = EnvironmentOps.LIST
         try:
             self._environment_execution_helper()
-            dx_logging.print_debug(">>> End Execution <<<")
+            dx_logging.print_debug("End of Execution")
             return True
         except Exception as err:
             dx_logging.print_exception(
@@ -242,7 +242,7 @@ class DXIEnvironment(DXIBase):
         self.ase_db_password = ase_db_password
         try:
             self._environment_execution_helper()
-            dx_logging.print_debug(">>> End Execution <<<")
+            dx_logging.print_debug("End of Execution")
             return True
         except Exception as err:
             dx_logging.print_exception(
@@ -260,7 +260,7 @@ class DXIEnvironment(DXIBase):
         self.action = EnvironmentOps.ENABLE
         try:
             self._environment_execution_helper()
-            dx_logging.print_debug(">>> End Execution <<<")
+            dx_logging.print_debug("End of Execution")
             return True
         except Exception as err:
             dx_logging.print_exception(
@@ -278,7 +278,7 @@ class DXIEnvironment(DXIBase):
         self.action = EnvironmentOps.DISABLE
         try:
             self._environment_execution_helper()
-            dx_logging.print_debug(">>> End Execution <<<")
+            dx_logging.print_debug("End of Execution")
             return True
         except Exception as err:
             dx_logging.print_exception(
@@ -296,7 +296,7 @@ class DXIEnvironment(DXIBase):
         self.action = EnvironmentOps.DELETE
         try:
             self._environment_execution_helper()
-            dx_logging.print_debug(">>> End Execution <<<")
+            dx_logging.print_debug("End of Execution")
             return True
         except Exception as err:
             dx_logging.print_exception(
@@ -314,7 +314,7 @@ class DXIEnvironment(DXIBase):
         self.action = EnvironmentOps.REFRESH
         try:
             self._environment_execution_helper()
-            dx_logging.print_debug(">>> End Execution <<<")
+            dx_logging.print_debug("End of Execution")
             return True
         except Exception as err:
             dx_logging.print_exception(
@@ -335,7 +335,7 @@ class DXIEnvironment(DXIBase):
         self.action = EnvironmentOps.UPDATEHOST
         try:
             self._environment_execution_helper()
-            dx_logging.print_debug(">>> End Execution <<<")
+            dx_logging.print_debug("End of Execution")
             return True
         except Exception as err:
             dx_logging.print_exception(
